summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/gtk/extensions/extension_popup_gtk.h
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-21 22:50:26 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-21 22:50:26 +0000
commit85131ae72bee932e59cfcec442109a568c6cc8b8 (patch)
tree7013e69c7919a8bc79ffd025e7fa5f5773ec6cb4 /chrome/browser/ui/gtk/extensions/extension_popup_gtk.h
parentcf4d5a246441d978a0c7d8abfa1b66d1f1512e66 (diff)
downloadchromium_src-85131ae72bee932e59cfcec442109a568c6cc8b8.zip
chromium_src-85131ae72bee932e59cfcec442109a568c6cc8b8.tar.gz
chromium_src-85131ae72bee932e59cfcec442109a568c6cc8b8.tar.bz2
gtk: Move bubble related files into ui/gtk/bubble directory.
Rename InfoBubbleGtk to BubbleGtk. Rename InfoBubbleGtkDelegate to BubbleDelegateGtk. Rename InfoBubbleAcceleratorsGtk To BubbleAcceleratorsGtk. This is a follow up to Ben's patch in http://codereview.chromium.org/6840026. BUG=72040 TEST=None R=estade@chromium.org Review URL: http://codereview.chromium.org/6865048 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@82570 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/gtk/extensions/extension_popup_gtk.h')
-rw-r--r--chrome/browser/ui/gtk/extensions/extension_popup_gtk.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/chrome/browser/ui/gtk/extensions/extension_popup_gtk.h b/chrome/browser/ui/gtk/extensions/extension_popup_gtk.h
index fa0d0c9..926bb2e 100644
--- a/chrome/browser/ui/gtk/extensions/extension_popup_gtk.h
+++ b/chrome/browser/ui/gtk/extensions/extension_popup_gtk.h
@@ -6,10 +6,11 @@
#define CHROME_BROWSER_UI_GTK_EXTENSIONS_EXTENSION_POPUP_GTK_H_
#pragma once
+#include "base/compiler_specific.h"
#include "base/memory/scoped_ptr.h"
#include "base/task.h"
+#include "chrome/browser/ui/gtk/bubble/bubble_gtk.h"
#include "chrome/browser/ui/gtk/extensions/extension_view_gtk.h"
-#include "chrome/browser/ui/gtk/info_bubble_gtk.h"
#include "content/common/notification_observer.h"
#include "content/common/notification_registrar.h"
#include "ui/gfx/rect.h"
@@ -19,7 +20,7 @@ class ExtensionHost;
class GURL;
class ExtensionPopupGtk : public NotificationObserver,
- public InfoBubbleGtkDelegate,
+ public BubbleDelegateGtk,
public ExtensionViewGtk::Container {
public:
ExtensionPopupGtk(Browser* browser,
@@ -36,18 +37,18 @@ class ExtensionPopupGtk : public NotificationObserver,
// NotificationObserver implementation.
virtual void Observe(NotificationType type,
const NotificationSource& source,
- const NotificationDetails& details);
+ const NotificationDetails& details) OVERRIDE;
- // InfoBubbleGtkDelegate implementation.
- virtual void InfoBubbleClosing(InfoBubbleGtk* bubble,
- bool closed_by_escape);
+ // BubbleDelegateGtk implementation.
+ virtual void BubbleClosing(BubbleGtk* bubble,
+ bool closed_by_escape) OVERRIDE;
- // ExtensionViewGtk::Container implementation
+ // ExtensionViewGtk::Container implementation.
virtual void OnExtensionPreferredSizeChanged(ExtensionViewGtk* view,
const gfx::Size& new_size);
// Destroys the popup widget. This will in turn destroy us since we delete
- // ourselves when the info bubble closes. Returns true if we successfully
+ // ourselves when the bubble closes. Returns true if we successfully
// closed the bubble.
bool DestroyPopup();
@@ -72,12 +73,12 @@ class ExtensionPopupGtk : public NotificationObserver,
Browser* browser_;
- InfoBubbleGtk* bubble_;
+ BubbleGtk* bubble_;
// We take ownership of the popup ExtensionHost.
scoped_ptr<ExtensionHost> host_;
- // The widget for anchoring the position of the info bubble.
+ // The widget for anchoring the position of the bubble.
GtkWidget* anchor_;
NotificationRegistrar registrar_;